@@ -87,20 +87,22 @@ var flagRules = []linter.FlagRule{
 		linter.RequireFlagNameLength(2, 20),
 		linter.ExcludeFlag(
 			"accepted-environments",
-			"azure-subscription-id",
+			"azure-subscription",
+			"certificate-authority-path",
+			"certificate-chain-filename",
 			"destination-api-key",
 			"destination-api-secret",
 			"destination-bootstrap-server",
 			"destination-cluster",
-			"remote-api-key",
-			"remote-api-secret",
-			"remote-bootstrap-server",
-			"remote-cluster",
 			"enable-systest-events",
 			"encrypted-key-material",
 			"max-partition-memory-bytes",
 			"message-send-max-retries",
 			"private-link-access-point",
+			"remote-api-key",
+			"remote-api-secret",
+			"remote-bootstrap-server",
+			"remote-cluster",
 			"request-required-acks",
 			"schema-registry-api-key",
 			"schema-registry-api-secret",
@@ -187,6 +189,7 @@ var vocabWords = []string{
 	"avro",
 	"aws",
 	"backoff",
+	"base64",
 	"byok",
 	"cel",
 	"cfu",
@@ -242,7 +245,6 @@ var vocabWords = []string{
 	"lz4",
 	"md",
 	"mds",
-	"netrc",
 	"nodejs",
 	"pem",
 	"plaintext",
