@@ -26,17 +26,12 @@ func (c *userCommand) newDeleteCommand() *cobra.Command {
 }
 
 func (c *userCommand) delete(cmd *cobra.Command, args []string) error {
-	user, err := c.V2Client.GetIamUserById(args[0])
-	if err != nil {
-		return resource.ResourcesNotFoundError(cmd, resource.User, args[0])
-	}
-
 	existenceFunc := func(id string) bool {
 		_, err := c.V2Client.GetIamUserById(id)
 		return err == nil
 	}
 
-	if err := deletion.ValidateAndConfirmDeletion(cmd, args, existenceFunc, resource.User, user.GetFullName()); err != nil {
+	if err := deletion.ValidateAndConfirm(cmd, args, existenceFunc, resource.User); err != nil {
 		return err
 	}
 
@@ -47,6 +42,6 @@ func (c *userCommand) delete(cmd *cobra.Command, args []string) error {
 		return nil
 	}
 
-	_, err = deletion.Delete(args, deleteFunc, resource.User)
+	_, err := deletion.Delete(args, deleteFunc, resource.User)
 	return err
 }
