@@ -12,10 +12,10 @@ type consumerCommand struct {
 }
 
 type consumerOut struct {
-	ConsumerGroupId string `human:"Consumer Group" serialized:"consumer_group_id"`
-	ConsumerId      string `human:"Consumer" serialized:"consumer_id"`
-	InstanceId      string `human:"Instance" serialized:"instance_id"`
-	ClientId        string `human:"Client" serialized:"client_id"`
+	ConsumerGroup string `human:"Consumer Group" serialized:"consumer_group"`
+	Consumer      string `human:"Consumer" serialized:"consumer"`
+	Instance      string `human:"Instance" serialized:"instance"`
+	Client        string `human:"Client" serialized:"client"`
 }
 
 func newConsumerCommand(cfg *config.Config, prerunner pcmd.PreRunner) *cobra.Command {
