@@ -9,15 +9,15 @@ import (
 	"github.com/confluentinc/cli/v3/pkg/output"
 )
 
-type describeOut struct {
-	Name                 string `human:"Name" serialized:"link_name"`
-	TopicName            string `human:"Topic Name" serialized:"topic_name"`
-	SourceClusterId      string `human:"Source Cluster" serialized:"source_cluster_id"`
-	DestinationClusterId string `human:"Destination Cluster" serialized:"destination_cluster_id"`
-	RemoteClusterId      string `human:"Remote Cluster" serialized:"remote_cluster_id"`
-	State                string `human:"State" serialized:"state"`
-	Error                string `human:"Error,omitempty" serialized:"error,omitempty"`
-	ErrorMessage         string `human:"Error Message,omitempty" serialized:"error_message,omitempty"`
+type linkOut struct {
+	Name               string `human:"Name" serialized:"link_name"`
+	TopicName          string `human:"Topic Name" serialized:"topic_name"`
+	SourceCluster      string `human:"Source Cluster" serialized:"source_cluster,omitempty"`
+	DestinationCluster string `human:"Destination Cluster" serialized:"destination_cluster,omitempty"`
+	RemoteCluster      string `human:"Remote Cluster" serialized:"remote_cluster,omitempty"`
+	State              string `human:"State" serialized:"state"`
+	Error              string `human:"Error,omitempty" serialized:"error,omitempty"`
+	ErrorMessage       string `human:"Error Message,omitempty" serialized:"error_message,omitempty"`
 }
 
 func (c *linkCommand) newDescribeCommand() *cobra.Command {
@@ -56,19 +56,19 @@ func (c *linkCommand) describe(cmd *cobra.Command, args []string) error {
 	return table.Print()
 }
 
-func newDescribeLink(link kafkarestv3.ListLinksResponseData, topic string) *describeOut {
+func newDescribeLink(link kafkarestv3.ListLinksResponseData, topic string) *linkOut {
 	var linkError string
 	if link.GetLinkError() != "NO_ERROR" {
 		linkError = link.GetLinkError()
 	}
-	return &describeOut{
-		Name:                 link.GetLinkName(),
-		TopicName:            topic,
-		SourceClusterId:      link.GetSourceClusterId(),
-		DestinationClusterId: link.GetDestinationClusterId(),
-		RemoteClusterId:      link.GetRemoteClusterId(),
-		State:                link.GetLinkState(),
-		Error:                linkError,
-		ErrorMessage:         link.GetLinkErrorMessage(),
+	return &linkOut{
+		Name:               link.GetLinkName(),
+		TopicName:          topic,
+		SourceCluster:      link.GetSourceClusterId(),
+		DestinationCluster: link.GetDestinationClusterId(),
+		RemoteCluster:      link.GetRemoteClusterId(),
+		State:              link.GetLinkState(),
+		Error:              linkError,
+		ErrorMessage:       link.GetLinkErrorMessage(),
 	}
 }
