@@ -24,17 +24,12 @@ func (c *quotaCommand) newDeleteCommand() *cobra.Command {
 }
 
 func (c *quotaCommand) delete(cmd *cobra.Command, args []string) error {
-	quota, err := c.V2Client.DescribeKafkaQuota(args[0])
-	if err != nil {
-		return resource.ResourcesNotFoundError(cmd, resource.ClientQuota, args[0])
-	}
-
 	existenceFunc := func(id string) bool {
 		_, err := c.V2Client.DescribeKafkaQuota(id)
 		return err == nil
 	}
 
-	if err := deletion.ValidateAndConfirmDeletion(cmd, args, existenceFunc, resource.ClientQuota, quota.Spec.GetDisplayName()); err != nil {
+	if err := deletion.ValidateAndConfirm(cmd, args, existenceFunc, resource.ClientQuota); err != nil {
 		return err
 	}
 
@@ -42,6 +37,6 @@ func (c *quotaCommand) delete(cmd *cobra.Command, args []string) error {
 		return c.V2Client.DeleteKafkaQuota(id)
 	}
 
-	_, err = deletion.Delete(args, deleteFunc, resource.ClientQuota)
+	_, err := deletion.Delete(args, deleteFunc, resource.ClientQuota)
 	return err
 }
