@@ -4,7 +4,6 @@ import (
 	"github.com/spf13/cobra"
 
 	pcmd "github.com/confluentinc/cli/v3/pkg/cmd"
-	"github.com/confluentinc/cli/v3/pkg/output"
 )
 
 func (c *quotaCommand) newDescribeCommand() *cobra.Command {
@@ -29,8 +28,5 @@ func (c *quotaCommand) describe(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	table := output.NewTable(cmd)
-	format := output.GetFormat(cmd)
-	table.Add(quotaToPrintable(quota, format))
-	return table.Print()
+	return printTable(cmd, quota)
 }
