@@ -10,7 +10,10 @@ import (
 )
 
 type topicOut struct {
-	Name string `human:"Name" serialized:"name"`
+	Name              string `human:"Name" serialized:"name"`
+	IsInternal        bool   `human:"Internal" serialized:"is_internal"`
+	ReplicationFactor int32  `human:"Replication Factor" serialized:"replication_factor"`
+	PartitionCount    int32  `human:"Partition Count" serialized:"partition_count"`
 }
 
 func (c *command) newListCommand() *cobra.Command {
@@ -38,7 +41,12 @@ func (c *command) list(cmd *cobra.Command, _ []string) error {
 
 	list := output.NewList(cmd)
 	for _, topic := range topics {
-		list.Add(&topicOut{Name: topic.GetTopicName()})
+		list.Add(&topicOut{
+			Name:              topic.GetTopicName(),
+			IsInternal:        topic.GetIsInternal(),
+			ReplicationFactor: topic.GetReplicationFactor(),
+			PartitionCount:    topic.GetPartitionsCount(),
+		})
 	}
 	return list.Print()
 }
