@@ -54,16 +54,6 @@ func (c *command) newExporterCreateCommand(cfg *config.Config) *cobra.Command {
 	cobra.CheckErr(cmd.Flags().MarkHidden("config-file"))
 	cmd.MarkFlagsMutuallyExclusive("config", "config-file")
 
-	if cfg.IsCloudLogin() {
-		// Deprecated
-		pcmd.AddApiKeyFlag(cmd, c.AuthenticatedCLICommand)
-		cobra.CheckErr(cmd.Flags().MarkHidden("api-key"))
-
-		// Deprecated
-		pcmd.AddApiSecretFlag(cmd)
-		cobra.CheckErr(cmd.Flags().MarkHidden("api-secret"))
-	}
-
 	return cmd
 }
 
