@@ -18,15 +18,12 @@ import (
 	"github.com/confluentinc/cli/v3/pkg/jwt"
 	"github.com/confluentinc/cli/v3/pkg/keychain"
 	"github.com/confluentinc/cli/v3/pkg/log"
-	"github.com/confluentinc/cli/v3/pkg/netrc"
 	"github.com/confluentinc/cli/v3/pkg/output"
 	"github.com/confluentinc/cli/v3/pkg/secret"
 )
 
 const stopNonInteractiveMsg = "remove these credentials or use the `--prompt` flag to bypass non-interactive login"
 
-var foundCredentialsForUserFromKeychainMessage = fmt.Sprintf(`Found credentials for user "%%s" from keychain (%s).`, stopNonInteractiveMsg)
-
 type Credentials struct {
 	Username string
 	Password string
@@ -47,10 +44,8 @@ func (c *Credentials) IsFullSet() bool {
 }
 
 type environmentVariables struct {
-	username           string
-	password           string
-	deprecatedUsername string
-	deprecatedPassword string
+	username string
+	password string
 }
 
 // Get login credentials using the functions from LoginCredentialsManager
@@ -73,10 +68,8 @@ func GetLoginCredentials(credentialsFuncs ...func() (*Credentials, error)) (*Cre
 type LoginCredentialsManager interface {
 	GetCloudCredentialsFromEnvVar(string) func() (*Credentials, error)
 	GetOnPremCredentialsFromEnvVar() func() (*Credentials, error)
-	GetSsoCredentialsFromConfig(*config.Config, string) func() (*Credentials, error)
-	GetCredentialsFromConfig(*config.Config, netrc.NetrcMachineParams) func() (*Credentials, error)
+	GetCredentialsFromConfig(*config.Config, config.MachineParams) func() (*Credentials, error)
 	GetCredentialsFromKeychain(bool, string, string) func() (*Credentials, error)
-	GetCredentialsFromNetrc(netrc.NetrcMachineParams) func() (*Credentials, error)
 	GetOnPremSsoCredentials(url, caCertPath string, unsafeTrace bool) func() (*Credentials, error)
 	GetOnPremSsoCredentialsFromConfig(*config.Config, bool) func() (*Credentials, error)
 	GetCloudCredentialsFromPrompt(string) func() (*Credentials, error)
@@ -84,32 +77,27 @@ type LoginCredentialsManager interface {
 
 	GetPrerunCredentialsFromConfig(*config.Config) func() (*Credentials, error)
 	GetOnPremPrerunCredentialsFromEnvVar() func() (*Credentials, error)
-	GetOnPremPrerunCredentialsFromNetrc(netrc.NetrcMachineParams) func() (*Credentials, error)
 
 	// Needed SSO login for non-prod accounts
 	SetCloudClient(*ccloudv1.Client)
 }
 
 type LoginCredentialsManagerImpl struct {
-	netrcHandler netrc.NetrcHandler
-	prompt       form.Prompt
-	client       *ccloudv1.Client
+	prompt form.Prompt
+	client *ccloudv1.Client
 }
 
-func NewLoginCredentialsManager(netrcHandler netrc.NetrcHandler, prompt form.Prompt, client *ccloudv1.Client) LoginCredentialsManager {
+func NewLoginCredentialsManager(prompt form.Prompt, client *ccloudv1.Client) LoginCredentialsManager {
 	return &LoginCredentialsManagerImpl{
-		netrcHandler: netrcHandler,
-		prompt:       prompt,
-		client:       client,
+		prompt: prompt,
+		client: client,
 	}
 }
 
 func (h *LoginCredentialsManagerImpl) GetCloudCredentialsFromEnvVar(organizationId string) func() (*Credentials, error) {
 	envVars := environmentVariables{
-		username:           ConfluentCloudEmail,
-		password:           ConfluentCloudPassword,
-		deprecatedUsername: DeprecatedConfluentCloudEmail,
-		deprecatedPassword: DeprecatedConfluentCloudPassword,
+		username: ConfluentCloudEmail,
+		password: ConfluentCloudPassword,
 	}
 	return h.getCredentialsFromEnvVarFunc(envVars, organizationId)
 }
@@ -122,16 +110,6 @@ func (h *LoginCredentialsManagerImpl) getCredentialsFromEnvVarFunc(envVars envir
 			return &Credentials{Username: email, IsSSO: true}, nil
 		}
 
-		if email == "" {
-			email, password = h.getEnvVarCredentials(envVars.deprecatedUsername, envVars.deprecatedPassword)
-			if email != "" {
-				output.ErrPrintf(false, errors.DeprecatedEnvVarWarningMsg, envVars.deprecatedUsername, envVars.username)
-			}
-			if password != "" {
-				output.ErrPrintf(false, errors.DeprecatedEnvVarWarningMsg, envVars.deprecatedPassword, envVars.password)
-			}
-		}
-
 		if password == "" {
 			log.CliLogger.Debug("Did not find full credential set from environment variables")
 			return nil, nil
@@ -156,15 +134,13 @@ func (h *LoginCredentialsManagerImpl) getEnvVarCredentials(userEnvVar, passwordE
 
 func (h *LoginCredentialsManagerImpl) GetOnPremCredentialsFromEnvVar() func() (*Credentials, error) {
 	envVars := environmentVariables{
-		username:           ConfluentPlatformUsername,
-		password:           ConfluentPlatformPassword,
-		deprecatedUsername: DeprecatedConfluentPlatformUsername,
-		deprecatedPassword: DeprecatedConfluentPlatformPassword,
+		username: ConfluentPlatformUsername,
+		password: ConfluentPlatformPassword,
 	}
 	return h.getCredentialsFromEnvVarFunc(envVars, "")
 }
 
-func (h *LoginCredentialsManagerImpl) GetCredentialsFromConfig(cfg *config.Config, filterParams netrc.NetrcMachineParams) func() (*Credentials, error) {
+func (h *LoginCredentialsManagerImpl) GetCredentialsFromConfig(cfg *config.Config, filterParams config.MachineParams) func() (*Credentials, error) {
 	return func() (*Credentials, error) {
 		var loginCredential *config.LoginCredential
 		ctx := cfg.Context()
@@ -197,29 +173,6 @@ func (h *LoginCredentialsManagerImpl) GetCredentialsFromConfig(cfg *config.Confi
 	}
 }
 
-func (h *LoginCredentialsManagerImpl) GetSsoCredentialsFromConfig(cfg *config.Config, url string) func() (*Credentials, error) {
-	return func() (*Credentials, error) {
-		ctx := cfg.Context()
-
-		if ctx.GetPlatformServer() != url {
-			return nil, nil
-		}
-
-		credentials := &Credentials{
-			IsSSO:            ctx.IsSso(),
-			Username:         ctx.GetUser().GetEmail(),
-			AuthToken:        ctx.GetAuthToken(),
-			AuthRefreshToken: ctx.GetAuthRefreshToken(),
-		}
-
-		if credentials.IsSSO {
-			return credentials, nil
-		}
-
-		return nil, nil
-	}
-}
-
 func (h *LoginCredentialsManagerImpl) GetPrerunCredentialsFromConfig(cfg *config.Config) func() (*Credentials, error) {
 	return func() (*Credentials, error) {
 		ctx := cfg.Context()
@@ -274,31 +227,6 @@ func (h *LoginCredentialsManagerImpl) GetOnPremSsoCredentialsFromConfig(cfg *con
 	}
 }
 
-func (h *LoginCredentialsManagerImpl) GetCredentialsFromNetrc(filterParams netrc.NetrcMachineParams) func() (*Credentials, error) {
-	return func() (*Credentials, error) {
-		netrcMachine, err := h.getNetrcMachine(filterParams)
-		if err != nil {
-			log.CliLogger.Debugf("Get netrc machine error: %s", err.Error())
-			return nil, err
-		}
-
-		log.CliLogger.Debugf(foundCredentialsForUserFromKeychainMessage, netrcMachine.User, h.netrcHandler.GetFileName())
-		return &Credentials{Username: netrcMachine.User, Password: netrcMachine.Password}, nil
-	}
-}
-
-func (h *LoginCredentialsManagerImpl) getNetrcMachine(filterParams netrc.NetrcMachineParams) (*netrc.Machine, error) {
-	log.CliLogger.Debugf("Searching for netrc machine with filter: %+v", filterParams)
-	netrcMachine, err := h.netrcHandler.GetMatchingNetrcMachine(filterParams)
-	if err != nil {
-		return nil, err
-	}
-	if netrcMachine == nil {
-		return nil, fmt.Errorf("found no netrc machine using the filter: %+v", filterParams)
-	}
-	return netrcMachine, err
-}
-
 func (h *LoginCredentialsManagerImpl) GetOnPremSsoCredentials(url, caCertPath string, unsafeTrace bool) func() (*Credentials, error) {
 	return func() (*Credentials, error) {
 		// For on-prem SSO logins, the sub claim of the Confluent Token is used in place of the Username
@@ -389,19 +317,17 @@ func (h *LoginCredentialsManagerImpl) isOnPremSSOUser(url, caCertPath string, un
 
 // Prerun login for Confluent has two extra environment variables settings: CONFLUENT_MDS_URL (required), CONFLUNET_CA_CERT_PATH (optional)
 // Those two variables are passed as flags for login command, but for prerun logins they are required as environment variables.
-// URL and ca-cert-path (if exists) are returned in addition to username and password
+// URL and certificate-authority-path (if exists) are returned in addition to username and password
 func (h *LoginCredentialsManagerImpl) GetOnPremPrerunCredentialsFromEnvVar() func() (*Credentials, error) {
 	return func() (*Credentials, error) {
-		url := GetEnvWithFallback(ConfluentPlatformMDSURL, DeprecatedConfluentPlatformMDSURL)
+		url := os.Getenv(ConfluentPlatformMDSURL)
 		if url == "" {
 			return nil, fmt.Errorf(errors.NoUrlEnvVarErrorMsg)
 		}
 
 		envVars := environmentVariables{
-			username:           ConfluentPlatformUsername,
-			password:           ConfluentPlatformPassword,
-			deprecatedUsername: DeprecatedConfluentPlatformUsername,
-			deprecatedPassword: DeprecatedConfluentPlatformPassword,
+			username: ConfluentPlatformUsername,
+			password: ConfluentPlatformPassword,
 		}
 
 		creds, _ := h.getCredentialsFromEnvVarFunc(envVars, "")()
@@ -409,31 +335,12 @@ func (h *LoginCredentialsManagerImpl) GetOnPremPrerunCredentialsFromEnvVar() fun
 			return nil, fmt.Errorf(errors.NoCredentialsFoundErrorMsg)
 		}
 		creds.PrerunLoginURL = url
-		creds.PrerunLoginCaCertPath = GetEnvWithFallback(ConfluentPlatformCACertPath, DeprecatedConfluentPlatformCACertPath)
+		creds.PrerunLoginCaCertPath = os.Getenv(ConfluentPlatformCertificateAuthorityPath)
 
 		return creds, nil
 	}
 }
 
-// Prerun login for Confluent will extract URL and ca-cert-path (if available) from the netrc machine name
-// URL is no longer part of the filter and URL value will be of whichever URL the first context stored in netrc has
-// URL and ca-cert-path (if exists) are returned in addition to username and password
-func (h *LoginCredentialsManagerImpl) GetOnPremPrerunCredentialsFromNetrc(netrcMachineParams netrc.NetrcMachineParams) func() (*Credentials, error) {
-	return func() (*Credentials, error) {
-		netrcMachine, err := h.getNetrcMachine(netrcMachineParams)
-		if err != nil {
-			log.CliLogger.Debugf("Get netrc machine error: %s", err.Error())
-			return nil, err
-		}
-		machineContextInfo, err := netrc.ParseNetrcMachineName(netrcMachine.Name)
-		if err != nil {
-			return nil, err
-		}
-		log.CliLogger.Debugf(foundCredentialsForUserFromKeychainMessage, netrcMachine.User, h.netrcHandler.GetFileName())
-		return &Credentials{Username: netrcMachine.User, Password: netrcMachine.Password, PrerunLoginURL: machineContextInfo.URL, PrerunLoginCaCertPath: machineContextInfo.CaCertPath}, nil
-	}
-}
-
 func (h *LoginCredentialsManagerImpl) GetCredentialsFromKeychain(isCloud bool, ctxName string, url string) func() (*Credentials, error) {
 	return func() (*Credentials, error) {
 		if runtime.GOOS == "darwin" {
@@ -452,7 +359,7 @@ func (h *LoginCredentialsManagerImpl) SetCloudClient(client *ccloudv1.Client) {
 	h.client = client
 }
 
-func matchLoginCredentialWithFilter(loginCredential *config.LoginCredential, filterParams netrc.NetrcMachineParams) bool {
+func matchLoginCredentialWithFilter(loginCredential *config.LoginCredential, filterParams config.MachineParams) bool {
 	if loginCredential == nil {
 		return false
 	}
