@@ -6,6 +6,7 @@ import (
 	billingv1 "github.com/confluentinc/ccloud-sdk-go-v2/billing/v1"
 	byokv1 "github.com/confluentinc/ccloud-sdk-go-v2/byok/v1"
 	cdxv1 "github.com/confluentinc/ccloud-sdk-go-v2/cdx/v1"
+	certificateauthorityv2 "github.com/confluentinc/ccloud-sdk-go-v2/certificate-authority/v2"
 	cliv1 "github.com/confluentinc/ccloud-sdk-go-v2/cli/v1"
 	cmkv2 "github.com/confluentinc/ccloud-sdk-go-v2/cmk/v2"
 	connectcustompluginv1 "github.com/confluentinc/ccloud-sdk-go-v2/connect-custom-plugin/v1"
@@ -23,7 +24,7 @@ import (
 	networkingv1 "github.com/confluentinc/ccloud-sdk-go-v2/networking/v1"
 	orgv2 "github.com/confluentinc/ccloud-sdk-go-v2/org/v2"
 	servicequotav1 "github.com/confluentinc/ccloud-sdk-go-v2/service-quota/v1"
-	srcmv2 "github.com/confluentinc/ccloud-sdk-go-v2/srcm/v2"
+	srcmv3 "github.com/confluentinc/ccloud-sdk-go-v2/srcm/v3"
 	ssov2 "github.com/confluentinc/ccloud-sdk-go-v2/sso/v2"
 	streamdesignerv1 "github.com/confluentinc/ccloud-sdk-go-v2/stream-designer/v1"
 
@@ -40,6 +41,7 @@ type Client struct {
 	BillingClient                *billingv1.APIClient
 	ByokClient                   *byokv1.APIClient
 	CdxClient                    *cdxv1.APIClient
+	CertificateAuthorityClient   *certificateauthorityv2.APIClient
 	CliClient                    *cliv1.APIClient
 	CmkClient                    *cmkv2.APIClient
 	ConnectClient                *connectv1.APIClient
@@ -57,7 +59,7 @@ type Client struct {
 	NetworkingPrivateLinkClient  *networkingprivatelinkv1.APIClient
 	OrgClient                    *orgv2.APIClient
 	ServiceQuotaClient           *servicequotav1.APIClient
-	SrcmClient                   *srcmv2.APIClient
+	SrcmClient                   *srcmv3.APIClient
 	SsoClient                    *ssov2.APIClient
 	StreamDesignerClient         *streamdesignerv1.APIClient
 }
@@ -80,6 +82,7 @@ func NewClient(cfg *config.Config, unsafeTrace bool) *Client {
 		BillingClient:                newBillingClient(httpClient, url, userAgent, unsafeTrace),
 		ByokClient:                   newByokV1Client(httpClient, url, userAgent, unsafeTrace),
 		CdxClient:                    newCdxClient(httpClient, url, userAgent, unsafeTrace),
+		CertificateAuthorityClient:   newCertificateAuthorityClient(httpClient, url, userAgent, unsafeTrace),
 		CliClient:                    newCliClient(url, userAgent, unsafeTrace),
 		CmkClient:                    newCmkClient(httpClient, url, userAgent, unsafeTrace),
 		ConnectClient:                newConnectClient(httpClient, url, userAgent, unsafeTrace),
