@@ -3,6 +3,7 @@ package cmd
 import (
 	"fmt"
 	"net/url"
+	"os"
 	"strings"
 
 	"github.com/spf13/cobra"
@@ -229,15 +230,15 @@ func (c *AuthenticatedCLICommand) GetSchemaRegistryClient(cmd *cobra.Command) (*
 			}
 			configuration.Servers = srsdk.ServerConfigurations{{URL: u.String()}}
 
-			caLocation, err := cmd.Flags().GetString("ca-location")
+			certificateAuthorityPath, err := cmd.Flags().GetString("certificate-authority-path")
 			if err != nil {
 				return nil, err
 			}
-			if caLocation == "" {
-				caLocation = auth.GetEnvWithFallback(auth.ConfluentPlatformCACertPath, auth.DeprecatedConfluentPlatformCACertPath)
+			if certificateAuthorityPath == "" {
+				certificateAuthorityPath = os.Getenv(auth.ConfluentPlatformCertificateAuthorityPath)
 			}
-			if caLocation != "" {
-				caClient, err := utils.GetCAClient(caLocation)
+			if certificateAuthorityPath != "" {
+				caClient, err := utils.GetCAClient(certificateAuthorityPath)
 				if err != nil {
 					return nil, err
 				}
