@@ -79,11 +79,6 @@ func AutocompleteByokKeyIds(client *ccloudv2.Client) []string {
 	return suggestions
 }
 
-func AddByokProviderFlag(cmd *cobra.Command) {
-	cmd.Flags().String("provider", "", fmt.Sprintf("Specify the provider as %s.", utils.ArrayToCommaDelimitedString([]string{"aws", "azure", "gcp"}, "or")))
-	RegisterFlagCompletionFunc(cmd, "provider", func(_ *cobra.Command, _ []string) []string { return []string{"aws", "azure", "gcp"} })
-}
-
 func AddByokStateFlag(cmd *cobra.Command) {
 	cmd.Flags().String("state", "", fmt.Sprintf("Specify the state as %s.", utils.ArrayToCommaDelimitedString([]string{"in-use", "available"}, "or")))
 	RegisterFlagCompletionFunc(cmd, "state", func(_ *cobra.Command, _ []string) []string { return []string{"in-use", "available"} })
@@ -212,6 +207,10 @@ func AddFilterFlag(cmd *cobra.Command) {
 	cmd.Flags().String("filter", "true", "A supported Common Expression Language (CEL) filter expression for group mappings.")
 }
 
+func AddExternalIdentifierFlag(cmd *cobra.Command) {
+	cmd.Flags().String("external-identifier", "", "External Identifier for this pool.")
+}
+
 func AutocompleteGroupMappings(client *ccloudv2.Client) []string {
 	groupMappings, err := client.ListGroupMappings()
 	if err != nil {
@@ -226,6 +225,20 @@ func AutocompleteGroupMappings(client *ccloudv2.Client) []string {
 	return suggestions
 }
 
+func AutocompleteCertificatePool(client *ccloudv2.Client, provider string) []string {
+	certificatePools, err := client.ListCertificatePool(provider)
+	if err != nil {
+		return nil
+	}
+
+	suggestions := make([]string, len(certificatePools))
+	for i, certificatePool := range certificatePools {
+		description := fmt.Sprintf("%s: %s", certificatePool.GetDisplayName(), certificatePool.GetDescription())
+		suggestions[i] = fmt.Sprintf("%s\t%s", certificatePool.GetId(), description)
+	}
+	return suggestions
+}
+
 func autocompleteKSQLClusters(environmentId string, client *ccloudv2.Client) []string {
 	clusters, err := client.ListKsqlClusters(environmentId)
 	if err != nil {
@@ -320,6 +333,19 @@ func AutocompleteIdentityProviders(client *ccloudv2.Client) []string {
 	return suggestions
 }
 
+func AutocompleteCertificateAuthorities(client *ccloudv2.Client) []string {
+	certificateAuthorities, err := client.ListCertificateAuthorities()
+	if err != nil {
+		return nil
+	}
+
+	suggestions := make([]string, len(certificateAuthorities))
+	for i, certificateAuthority := range certificateAuthorities {
+		suggestions[i] = fmt.Sprintf("%s\t%s", certificateAuthority.GetId(), certificateAuthority.GetDisplayName())
+	}
+	return suggestions
+}
+
 func AutocompleteIdentityPools(client *ccloudv2.Client, providerId string) []string {
 	identityPools, err := client.ListIdentityPools(providerId)
 	if err != nil {
