@@ -20,7 +20,7 @@ var (
 	mockEmail              = "cli-mock-email@confluent.io"
 	mockURL                = "http://test"
 	usernameCredentialName = fmt.Sprintf("username-%s-%s", mockEmail, mockURL)
-	mockContextName        = fmt.Sprintf("login-%s-%s", mockEmail, mockURL)
+	MockContextName        = fmt.Sprintf("login-%s-%s", mockEmail, mockURL)
 	mockAuthToken          = "some.token.here"
 
 	// kafka cluster
@@ -37,7 +37,7 @@ func AuthenticatedCloudConfigMock() *Config {
 
 func AuthenticatedToOrgCloudConfigMock(orgId int32, orgResourceId string) *Config {
 	params := mockConfigParams{
-		contextName:    mockContextName,
+		contextName:    MockContextName,
 		userId:         mockUserId,
 		userResourceId: MockUserResourceId,
 		username:       mockEmail,
@@ -52,7 +52,7 @@ func AuthenticatedToOrgCloudConfigMock(orgId int32, orgResourceId string) *Confi
 
 func AuthenticatedOnPremConfigMock() *Config {
 	params := mockConfigParams{
-		contextName:    mockContextName,
+		contextName:    MockContextName,
 		userId:         mockUserId,
 		userResourceId: MockUserResourceId,
 		username:       mockEmail,
