@@ -8,8 +8,8 @@ import (
 
 	"github.com/keybase/go-keychain"
 
+	"github.com/confluentinc/cli/v3/pkg/config"
 	"github.com/confluentinc/cli/v3/pkg/log"
-	"github.com/confluentinc/cli/v3/pkg/netrc"
 )
 
 const (
@@ -18,7 +18,7 @@ const (
 )
 
 func Write(isCloud bool, ctxName, url, username, password string) error {
-	service := netrc.GetLocalCredentialName(isCloud, ctxName)
+	service := config.GetLocalCredentialName(isCloud, ctxName)
 
 	item := keychain.NewGenericPassword(service, url, fmt.Sprintf("%s-%s", username, url), []byte(username+separator+password), accessGroup)
 	item.SetSynchronizable(keychain.SynchronizableNo)
@@ -33,7 +33,7 @@ func Write(isCloud bool, ctxName, url, username, password string) error {
 }
 
 func Delete(isCloud bool, ctxName string) error {
-	service := netrc.GetLocalCredentialName(isCloud, ctxName)
+	service := config.GetLocalCredentialName(isCloud, ctxName)
 
 	item := keychain.NewItem()
 	item.SetSecClass(keychain.SecClassGenericPassword)
@@ -68,7 +68,7 @@ func Read(isCloud bool, ctxName, url string) (string, string, error) {
 	item.SetReturnData(true)
 
 	if ctxName != "" {
-		service := netrc.GetLocalCredentialName(isCloud, ctxName)
+		service := config.GetLocalCredentialName(isCloud, ctxName)
 		item.SetService(service)
 	}
 
