@@ -1,6 +1,8 @@
 package output
 
-import "github.com/spf13/cobra"
+import (
+	"github.com/spf13/cobra"
+)
 
 type Format int
 
