@@ -18,6 +18,8 @@ const (
 	ApiKey                          = "API key"
 	Broker                          = "broker"
 	ByokKey                         = "self-managed key"
+	CertificateAuthority            = "certificate authority"
+	CertificatePool                 = "certificate pool"
 	ClientQuota                     = "client quota"
 	Cloud                           = "cloud"
 	ClusterLink                     = "cluster link"
@@ -48,6 +50,7 @@ const (
 	NetworkLinkServiceAssociation   = "network link service association"
 	Organization                    = "organization"
 	Peering                         = "peering"
+	Plugin                          = "plugin"
 	PrivateLinkAccess               = "private link access"
 	PrivateLinkAttachment           = "private link attachment"
 	PrivateLinkAttachmentConnection = "private link attachment connection"
@@ -184,7 +187,7 @@ func ResourcesNotFoundError(cmd *cobra.Command, resourceType string, invalidArgs
 		fullParentCommand = fmt.Sprintf("%s %s", cmd.Parent().Name(), fullParentCommand)
 		cmd = cmd.Parent()
 	}
-	invalidResourceSuggestion := fmt.Sprintf(errors.ListResourceSuggestions, resourceType, fullParentCommand)
+	invalidResourceSuggestion := fmt.Sprintf("List available %s with `%s list`.", Plural(resourceType), fullParentCommand)
 
 	return errors.NewErrorWithSuggestions(invalidArgsErrMsg, invalidResourceSuggestion)
 }
@@ -194,6 +197,11 @@ func Plural(resource string) string {
 		return ""
 	}
 
+	// Words ending in `-ty` generally replace it with `-ties` in their plural forms
+	if strings.HasSuffix(resource, "ty") {
+		return strings.TrimSuffix(resource, "y") + "ies"
+	}
+
 	// Singular words ending w/ these suffixes generally add an extra -es syllable in their plural forms
 	var pluralExtraSyllableSuffix = types.NewSet("s", "x", "z", "ch", "sh")
 
