@@ -41,7 +41,7 @@ func (s *CLITestSuite) TestFlinkArtifact() {
 		{args: "flink artifact describe ccp-789013", fixture: "flink/artifact/describe.golden"},
 		{args: "flink artifact list", fixture: "flink/artifact/list.golden"},
 		{args: "flink artifact delete ccp-123456 --force", fixture: "flink/artifact/delete.golden"},
-		{args: "flink artifact delete ccp-123456", input: "CliPluginTest1\n", fixture: "flink/artifact/delete-prompt.golden"},
+		{args: "flink artifact delete ccp-123456", input: "y\n", fixture: "flink/artifact/delete-prompt.golden"},
 	}
 
 	for _, test := range tests {
@@ -55,7 +55,7 @@ func (s *CLITestSuite) TestFlinkComputePool() {
 		{args: "flink compute-pool create my-compute-pool --cloud aws --region us-west-2", fixture: "flink/compute-pool/create.golden"},
 		{args: "flink compute-pool describe lfcp-123456", fixture: "flink/compute-pool/describe.golden"},
 		{args: "flink compute-pool list", fixture: "flink/compute-pool/list.golden"},
-		{args: "flink compute-pool list --region us-west-2", fixture: "flink/compute-pool/list-region.golden"},
+		{args: "flink compute-pool list --region eu-west-2", fixture: "flink/compute-pool/list-region.golden"},
 		{args: "flink compute-pool update lfcp-123456 --max-cfu 5", fixture: "flink/compute-pool/update.golden"},
 	}
 
@@ -150,6 +150,8 @@ func (s *CLITestSuite) TestFlinkStatement() {
 		{args: "flink statement list --cloud aws --region eu-west-1 -o yaml", fixture: "flink/statement/list-yaml.golden"},
 		{args: "flink statement list --cloud aws --region eu-west-1 --status completed", fixture: "flink/statement/list-completed.golden"},
 		{args: "flink statement list --cloud aws --region eu-west-1 --status pending", fixture: "flink/statement/list-pending.golden"},
+		{args: "flink statement list --cloud aws --region eu-west-1 --compute-pool lfcp-nonexistent", fixture: "flink/statement/list-cp-not-found.golden", exitCode: 1},
+		{args: "flink statement list --cloud aws --region eu-west-2 --compute-pool lfcp-123456", fixture: "flink/statement/list-cp-incorrect-region.golden", exitCode: 1},
 		{args: "flink statement describe my-statement --cloud aws --region eu-west-1", fixture: "flink/statement/describe.golden"},
 		{args: "flink statement describe my-statement --cloud aws --region eu-west-1 -o yaml", fixture: "flink/statement/describe-yaml.golden"},
 		{args: "flink statement stop my-statement --region eu-west-1 --cloud aws", fixture: "flink/statement/stop.golden"},
