@@ -14,7 +14,6 @@ import (
 	pauth "github.com/confluentinc/cli/v3/pkg/auth"
 	"github.com/confluentinc/cli/v3/pkg/config"
 	"github.com/confluentinc/cli/v3/pkg/errors"
-	"github.com/confluentinc/cli/v3/pkg/netrc"
 	testserver "github.com/confluentinc/cli/v3/test/test-server"
 )
 
@@ -199,10 +198,9 @@ func (s *CLITestSuite) TestLogin_SaveUsernamePassword() {
 
 		require.NotNil(s.T(), cfg.SavedCredentials["login-good@user.com-"+test.loginURL])
 	}
-	_ = os.Remove(netrc.IntegrationTestFile)
 }
 
-func (s *CLITestSuite) TestLogin_UpdateNetrcPassword() {
+func (s *CLITestSuite) TestLogin_UpdateSavedPassword() {
 	tests := []struct {
 		isCloud  bool
 		loginURL string
@@ -252,7 +250,6 @@ func (s *CLITestSuite) TestLogin_UpdateNetrcPassword() {
 
 		s.NotEqual(oldData.SavedCredentials, data.SavedCredentials)
 	}
-	_ = os.Remove(netrc.IntegrationTestFile)
 }
 
 func (s *CLITestSuite) TestLogin_MdsUrl() {
@@ -277,7 +274,7 @@ func (s *CLITestSuite) TestLogin_CaCertPath() {
 	tests := []CLITest{
 		{
 			env:  []string{"CONFLUENT_PLATFORM_USERNAME=on-prem@example.com", "CONFLUENT_PLATFORM_PASSWORD=password"},
-			args: fmt.Sprintf("login --url %s --ca-cert-path test/fixtures/input/login/test.crt", s.TestBackend.GetMdsUrl()),
+			args: fmt.Sprintf("login --url %s --certificate-authority-path test/fixtures/input/login/test.crt", s.TestBackend.GetMdsUrl()),
 		},
 		{
 			args:    "context list -o yaml",
@@ -298,7 +295,7 @@ func (s *CLITestSuite) TestLogin_MdsSso() {
 	defer func() { testserver.IsSsoEnabled = false }()
 
 	tests := []CLITest{
-		{args: fmt.Sprintf("login --no-browser --url %s --ca-cert-path test/fixtures/input/login/test.crt", s.TestBackend.GetMdsUrl())},
+		{args: fmt.Sprintf("login --no-browser --url %s --certificate-authority-path test/fixtures/input/login/test.crt", s.TestBackend.GetMdsUrl())},
 		{args: "context list -o yaml", fixture: "login/mds-sso.golden", regex: true},
 	}
 
