@@ -44,6 +44,8 @@ var ccloudV2Routes = []route{
 	{"/fcpm/v2/regions", handleFcpmRegions},
 	{"/iam/v2/api-keys", handleIamApiKeys},
 	{"/iam/v2/api-keys/{id}", handleIamApiKey},
+	{"/iam/v2/certificate-authorities/{id}", handleIamCertificateAuthority},
+	{"/iam/v2/certificate-authorities", handleIamCertificateAuthorities},
 	{"/iam/v2/identity-providers", handleIamIdentityProviders},
 	{"/iam/v2/identity-providers/{id}", handleIamIdentityProvider},
 	{"/iam/v2/identity-providers/{provider_id}/identity-pools", handleIamIdentityPools},
@@ -59,6 +61,8 @@ var ccloudV2Routes = []route{
 	{"/iam/v2/service-accounts/{id}", handleIamServiceAccount},
 	{"/iam/v2/sso/group-mappings", handleIamGroupMappings},
 	{"/iam/v2/sso/group-mappings/{id}", handleIamGroupMapping},
+	{"/iam/v2/certificate-authorities/{provider_id}/identity-pools", handleIamCertificatePools},
+	{"/iam/v2/certificate-authorities/{provider_id}/identity-pools/{id}", handleIamCertificatePool},
 	{"/iam/v2/users", handleIamUsers},
 	{"/iam/v2/users/{id}", handleIamUser},
 	{"/kafka-quotas/v1/client-quotas", handleKafkaClientQuotas},
@@ -100,10 +104,8 @@ var ccloudV2Routes = []route{
 	{"/sd/v1/pipelines/{id}", handlePipeline},
 	{"/service-quota/v1/applied-quotas", handleAppliedQuotas},
 	{"/service-quota/v2/applied-quotas", handleAppliedQuotas},
-	{"/srcm/v2/clusters", handleSchemaRegistryClusters},
-	{"/srcm/v2/clusters/{id}", handleSchemaRegistryCluster},
-	{"/srcm/v2/regions", handleSchemaRegistryRegions},
-	{"/srcm/v2/regions/{id}", handleSchemaRegistryRegion},
+	{"/srcm/v3/clusters", handleSchemaRegistryClustersV3},
+	{"/srcm/v3/clusters/{id}", handleSchemaRegistryClusterV3},
 	{"/v2/metrics/cloud/query", handleMetricsQuery},
 }
 
